Class: CliConfirm

Inherits:
Gloo::Core::Obj
  • Object
show all
Defined in:
lib/cli_confirm.rb

Overview

Author

Eric Crane (eric.crane@mac.com)

Copyright

Copyright © 2019 Eric Crane. All rights reserved.

Show a CLI confirmation prompt.

Constant Summary collapse

KEYWORD =
'confirm'.freeze
KEYWORD_SHORT =
'confirm'.freeze
PROMPT =
'prompt'.freeze
DEFAULT_PROMPT =
'> '.freeze
RESULT =
'result'.freeze

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.messagesObject

Get a list of message names that this object receives.



77
78
79
# File 'lib/cli_confirm.rb', line 77

def self.messages
  return super + [ 'run' ]
end

.short_typenameObject

The short name of the object type.



25
26
27
# File 'lib/cli_confirm.rb', line 25

def self.short_typename
  return KEYWORD_SHORT
end

.typenameObject

The name of the object type.



18
19
20
# File 'lib/cli_confirm.rb', line 18

def self.typename
  return KEYWORD
end

Instance Method Details

#add_children_on_create?Boolean

Does this object have children to add when an object is created in interactive mode? This does not apply during obj load, etc.

Returns:

  • (Boolean)


57
58
59
# File 'lib/cli_confirm.rb', line 57

def add_children_on_create?
  return true
end

#add_default_childrenObject

Add children to this object. This is used by containers to add children needed for default configurations.



64
65
66
67
68
# File 'lib/cli_confirm.rb', line 64

def add_default_children
  fac = @engine.factory
  fac.create_string PROMPT, DEFAULT_PROMPT, self
  fac.create_bool RESULT, nil, self
end

#msg_runObject

Run the confirmation command.



84
85
86
87
88
89
90
# File 'lib/cli_confirm.rb', line 84

def msg_run
  prompt = prompt_value
  return unless prompt

  result = @engine.platform.prompt.yes?( prompt )
  set_result result
end

#prompt_valueObject

Get the URI from the child object. Returns nil if there is none.



33
34
35
36
37
38
# File 'lib/cli_confirm.rb', line 33

def prompt_value
  o = find_child PROMPT
  return nil unless o

  return o.value
end

#set_result(data) ⇒ Object

Set the result of the system call.



43
44
45
46
47
48
# File 'lib/cli_confirm.rb', line 43

def set_result( data )
  r = find_child RESULT
  return nil unless r

  r.set_value data
end